@@ -13,10 +13,10 @@
 #    under the License.
 
 import collections
+from collections import abc
 import logging
 
 import ovs.db.idl
-import six
 
 from ovsdbapp import api
 from ovsdbapp.backend.ovs_idl import idlutils
@@ -35,9 +35,8 @@ class BaseCommand(api.Command):
     def execute(self, check_error=False, log_errors=True, **kwargs):
         try:
             if self.READ_ONLY:
-                with self.api.ovsdb_connection.lock:
-                    self.run_idl(None)
-                    return self.result
+                self.run_idl(None)
+                return self.result
             with self.api.transaction(check_error, log_errors, **kwargs) as t:
                 t.add(self)
             return self.result
@@ -134,7 +133,7 @@ class DbSetCommand(BaseCommand):
     def run_idl(self, txn):
         record = self.api.lookup(self.table, self.record)
         for col, val in self.col_values:
-            if isinstance(val, collections.Mapping):
+            if isinstance(val, abc.Mapping):
                 # TODO(twilson) This is to make a unit/functional test that
                 # used OrderedDict work. In Python 3.7, insertion order is
                 # guaranteed to not change, but I need to verify this is is
@@ -167,13 +166,13 @@ class DbAddCommand(BaseCommand):
     def run_idl(self, txn):
         record = self.api.lookup(self.table, self.record)
         for value in self.values:
-            if isinstance(value, collections.Mapping):
+            if isinstance(value, abc.Mapping):
                 # We should be doing an add on a 'map' column. If the key is
                 # already set, do nothing, otherwise set the key to the value
                 # Since this operation depends on the previous value, verify()
                 # must be called.
                 field = getattr(record, self.column, {})
-                for k, v in six.iteritems(value):
+                for k, v in value.items():
                     if k in field:
                         continue
                     field[k] = v
@@ -253,16 +252,23 @@ class DbListCommand(ReadOnlyCommand):
             rows = table_schema.rows.values()
 
         def _match(row):
+            elem = getattr(row, idx)
+            return elem in self.records
+
+        def _match_remove(row):
             elem = getattr(row, idx)
             found = elem in self.records
             if found:
                 records_found.remove(elem)
             return found
 
+        def _match_true(row):
+            return True
+
         records_found = []
         if idx and self.records:
             if self.if_exists:
-                match = lambda row: getattr(row, idx) in self.records
+                match = _match
             else:
                 # If we're using the approach of removing the unwanted
                 # elements, we'll use a helper list to remove elements as we
@@ -270,9 +276,9 @@ class DbListCommand(ReadOnlyCommand):
                 # quickly if there's some record missing to raise a RowNotFound
                 # exception later.
                 records_found = list(self.records)
-                match = _match
+                match = _match_remove
         else:
-            match = lambda row: True
+            match = _match_true
 
         self.result = [
             rowview.RowView(row) if self.row else {
@@ -343,5 +349,4 @@ class DbRemoveCommand(BaseCommand):
         except idlutils.RowNotFound:
             if self.if_exists:
                 return
-            else:
-                raise
+            raise
