@@ -13,36 +13,17 @@
 #    under the License.
 
 import collections
+from collections import abc
 import logging
 import os
 import sys
 import time
 import uuid
 
-# custom_index.py added in ovs 2.10. We just need the IndexEntryClass function
-# which is copied from OVS below since the current lower constraint is < 2.10
-try:
-    from ovs.db.custom_index import IndexEntryClass
-except ImportError:
-    from ovs.db import data
-
-    def IndexEntryClass(table):
-        def defaults_uuid_to_row(atom, base):
-            return atom.value
-
-        columns = ['uuid'] + list(table.columns.keys())
-        cls = collections.namedtuple(table.name, columns)
-        cls._table = table
-        cls.__new__.__defaults__ = (None,) + tuple(
-            data.Datum.default(c.type).to_python(defaults_uuid_to_row)
-            for c in table.columns.values())
-        return cls
-
 from ovs.db import idl
 from ovs import jsonrpc
 from ovs import poller
 from ovs import stream
-import six
 
 from ovsdbapp import api
 from ovsdbapp import exceptions
@@ -73,12 +54,42 @@ class RowNotFound(exceptions.OvsdbAppException):
     message = "Cannot find %(table)s with %(col)s=%(match)s"
 
 
+def index_name(*columns):
+    assert columns
+    return "_".join(sorted(columns))
+
+
+def index_lookup(table, **matches):
+    """Find a value in Table by index
+
+    :param table:   The table to search in
+    :type table:    ovs.db.schema.TableSchema
+    :param matches: The column/value pairs of the index to search
+    :type matches:  The types of the columns being matched
+    :returns:       A Row object
+    """
+    idx = table.rows.indexes[index_name(*matches.keys())]
+    search = table.rows.IndexEntry(**matches)
+    return next(idx.irange(search, search))
+
+
+def table_lookup(table, column, match):
+    return next(r for r in table.rows.values() if getattr(r, column) == match)
+
+
 def row_by_value(idl_, table, column, match, default=_NO_DEFAULT):
     """Lookup an IDL row in a table by column/value"""
     tab = idl_.tables[table]
-    for r in tab.rows.values():
-        if getattr(r, column) == match:
-            return r
+    try:
+        return index_lookup(tab, **{column: match})
+    except KeyError:  # no index column
+        try:
+            return table_lookup(tab, column, match)
+        except StopIteration:
+            pass
+    except StopIteration:  # match not found via index
+        pass
+
     if default is not _NO_DEFAULT:
         return default
     raise RowNotFound(table=table, col=column, match=match)
@@ -229,7 +240,7 @@ def condition_match(row, condition):
     #                I haven't investigated the reason for the patch that
     #                added this code, but for now I check string_types
     if type(match) is not type(val) and not all(
-        isinstance(x, six.string_types) for x in (match, val)):
+            isinstance(x, str) for x in (match, val)):
         # Types of 'val' and 'match' arguments MUST match in all cases with 2
         # exceptions:
         # - 'match' is an empty list and column's type is optional;
@@ -312,12 +323,12 @@ def db_replace_record(obj):
     This method should leave obj untouched unless the object contains an
     api.Command object.
     """
-    if isinstance(obj, collections.Mapping):
-        for k, v in six.iteritems(obj):
+    if isinstance(obj, abc.Mapping):
+        for k, v in obj.items():
             if isinstance(v, api.Command):
                 obj[k] = v.result
-    elif (isinstance(obj, collections.Sequence)
-          and not isinstance(obj, six.string_types)):
+    elif (isinstance(obj, abc.Sequence) and
+          not isinstance(obj, str)):
         for i, v in enumerate(obj):
             if isinstance(v, api.Command):
                 try:
@@ -340,23 +351,3 @@ def row2str(row):
     return "%s(%s)" % (row._table.name, ", ".join(
         "%s=%s" % (col, idl._row_to_uuid(getattr(row, col)))
         for col in row._table.columns if hasattr(row, col)))
-
-
-def frozen_row(row):
-    """Return a namedtuple representation of a idl.Row object
-
-    Row objects are inherently tied to the transaction processing of the Idl.
-    This means that if you have a reference to a Row in one thread, and
-    another thread starts a transaction that modifies that row, the Row can
-    change w/o you knowing it. This is especially noticeable when using the
-    RowEventHandler. It is possible for a Row that is passed to notify() by
-    the Idl class to change between being matched and the RowEvent.run()
-    method being called. This returns an immutable representation of the row
-    by using the same class that custom indexes use for searching. This
-    should be safe to pass to other threads.
-    """
-    IndexEntry = IndexEntryClass(row._table)
-    return IndexEntry(
-        uuid=row.uuid,
-        **{col: getattr(row, col)
-           for col in row._table.columns if hasattr(row, col)})
