@@ -12,14 +12,11 @@
 
 import abc
 
-import six
-
 from ovsdbapp import api
 from ovsdbapp import constants as const
 
 
-@six.add_metaclass(abc.ABCMeta)
-class API(api.API):
+class API(api.API, metaclass=abc.ABCMeta):
     """An API based off of the ovn-nbctl CLI interface
 
     This API basically mirrors the ovn-nbctl operations with these changes:
